@@ -89,19 +89,19 @@ define([
 								'<form>\
 								<div class="form-group">\
 								<label for="server">Server: </label>\
-								<input class="form-control" id="server" type="text" placeholder="localhost">\
+								<input class="form-control" id="server" type="text">\
 								</div>\
 								<div class="form-group">\
 								<label for="port">Port: </label>\
-								<input class="form-control" id="port" type="text" placeholder="8848">\
+								<input class="form-control" id="port" type="text">\
 								</div>\
 								<div class="form-group">\
 								<label for="username">Username: </label>\
-								<input class="form-control" id="username" type="text" placeholder="admin">\
+								<input class="form-control" id="username" type="text">\
 								</div>\
 								<div class="form-group">\
 								<label for="password">Password: </label>\
-								<input class="form-control" id="password" type="password" placeholder="123456">\
+								<input class="form-control" id="password" type="password">\
 								</div>\
 								</form>'
 							);
